<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hu_HU">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About %1</source>
        <translation>Névjegy: %1</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Szerzők</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Licenc</translation>
    </message>
    <message>
        <source>Lightweight WebKit-based web browser</source>
        <translation>WebKit-alapú böngésző</translation>
    </message>
    <message utf8="true">
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Minden jog fenntartva © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
    <message>
        <source>WebKit version: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AcceptLanguage</name>
    <message>
        <source>Languages</source>
        <translation>Nyelvek</translation>
    </message>
    <message>
        <source>Languages: in order of preference:</source>
        <translation>Nyelvek: prferencia szerint rendezve:</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>&amp;Fel</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>&amp;Le</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Eltávolítás</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Hozzáadás...</translation>
    </message>
</context>
<context>
    <name>AdBlockBlockedNetworkReply</name>
    <message>
        <source>Blocked by AdBlockRule: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockDialog</name>
    <message>
        <source>Add Custom Rule</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Learn more about writing rules...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Subscription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse Subscriptions...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Subscription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AdBlock Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable AdBlock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockManager</name>
    <message>
        <source>Custom Rules</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockModel</name>
    <message>
        <source>Rule</source>
        <translation type="unfinished">Szabály</translation>
    </message>
</context>
<context>
    <name>AdBlockSchemeAccessHandler</name>
    <message>
        <source>Subscribe?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subscribe to this AdBlock subscription?
%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddBookmarkDialog</name>
    <message>
        <source>Add Bookmark</source>
        <translation>Hozzáadás a könyvjelzőkhöz</translation>
    </message>
    <message>
        <source>Type a name for the bookmark, and choose where to keep it.</source>
        <translation>Adja meg a könyvjelző nevét és jelölje ki a helyét.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Hivatkozás</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Cím</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Új könyvjelzőmappa</translation>
    </message>
</context>
<context>
    <name>AutoFillDialog</name>
    <message>
        <source>Form Passwords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished">Eltávolítás</translation>
    </message>
    <message>
        <source>Remove All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoFillManager</name>
    <message>
        <source>&lt;b&gt;Would you like to save this password?&lt;/b&gt;&lt;br&gt;         To review passwords you have saved and remove them, open the AutoFill pane of preferences.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Never for this site</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not now</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoFillModel</name>
    <message>
        <source>WebSite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksDialog</name>
    <message>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <source>Open in New Tab</source>
        <translation>Megnyitás új lapon</translation>
    </message>
    <message>
        <source>Edit Name</source>
        <translation>Név szerkesztése</translation>
    </message>
    <message>
        <source>Edit Address</source>
        <translation>Cím szerkesztése</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Új könyvjelzőmappa</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Könyvjelzők</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Eltávolítás</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Új könyvjelzőmappa</translation>
    </message>
</context>
<context>
    <name>BookmarksManager</name>
    <message>
        <source>Bookmarks Bar</source>
        <translation>Könyvjelző eszköztár</translation>
    </message>
    <message>
        <source>Bookmarks Menu</source>
        <translation>Könyvjelző menü</translation>
    </message>
    <message>
        <source>Error when loading bookmarks on line %1, column %2:
%3</source>
        <translation>Hiba a könyvjelzők betöltése közben a(z) %1. sor %2. oszlopban:
%3</translation>
    </message>
    <message>
        <source>Toolbar Bookmarks</source>
        <translation>Könyvjelző eszköztár</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Menü</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Fájl megnyitása</translation>
    </message>
    <message>
        <source>XBEL</source>
        <translation type="obsolete">XBEL</translation>
    </message>
    <message>
        <source>Error when loading html bookmarks: %1
</source>
        <translation type="obsolete">Hiba a html könyvjelzők betöltése közben: %1
</translation>
    </message>
    <message>
        <source>Imported %1</source>
        <translation>%1 importálva</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Fájl mentése</translation>
    </message>
    <message>
        <source>%1 Bookmarks.xbel</source>
        <translation>%1 Konyvjelzok.xbel</translation>
    </message>
    <message>
        <source>XBEL (*.xbel *.xml)</source>
        <translation type="obsolete">lupdate ../src/src.pro</translation>
    </message>
    <message>
        <source>Export error</source>
        <translation>Hiba az exportálás közben</translation>
    </message>
    <message>
        <source>error saving bookmarks</source>
        <translation>Hiba a könyvjelzők mentése közben</translation>
    </message>
    <message>
        <source>Remove Bookmark</source>
        <translation>Könyvjelző eltávolítása</translation>
    </message>
    <message>
        <source>Insert Bookmark</source>
        <translation>Könyvjelző hozzáadása</translation>
    </message>
    <message>
        <source>Name Change</source>
        <comment>Undo bookmark title change</comment>
        <translation>Név megváltoztatása</translation>
    </message>
    <message>
        <source>Address Change</source>
        <comment>Undo bookmark url change</comment>
        <translation>Hivatkozás megváltoztatása</translation>
    </message>
    <message>
        <source>XBEL bookmarks</source>
        <translation>XBEL könyvjelzők</translation>
    </message>
    <message>
        <source>HTML Netscape bookmarks</source>
        <translation>HTML Netscape könyvjelzők</translation>
    </message>
    <message>
        <source>htmlToXBel tool required</source>
        <translation>htmlToXBel eszköz szükséges</translation>
    </message>
    <message>
        <source>htmlToXBel tool, which is shipped with Arora and is needed to import HTML bookmarks, is not installed or not available in the search paths.</source>
        <translation>A HTML könyvjelzők importálására szolgáló, az Arora részeként szállított htmlToXBel eszköz nincs telepítve, vagy nem érhető el a keresési útvonalon.</translation>
    </message>
    <message>
        <source>Loading Bookmark</source>
        <translation>Könyvjelző betöltése</translation>
    </message>
    <message>
        <source>Error when loading HTML bookmarks: %1
</source>
        <translation>Hiba a HTML könyvjelzők betöltése közben: %1
</translation>
    </message>
</context>
<context>
    <name>BookmarksMenu</name>
    <message>
        <source>Open in Tabs</source>
        <translation>Megnyitás lapokon</translation>
    </message>
</context>
<context>
    <name>BookmarksModel</name>
    <message>
        <source>Title</source>
        <translation>Cím</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Hivatkozás</translation>
    </message>
</context>
<context>
    <name>BookmarksToolBar</name>
    <message>
        <source>Bookmark</source>
        <translation type="obsolete">Könyvjelző</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>Megnyitás új la&amp;pon</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eltávolítás</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Könyvjelző hozzáadása...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation>Könyvjelzőmappa hozzáadása...</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation type="obsolete">Könyvjelzők</translation>
    </message>
</context>
<context>
    <name>BrowserApplication</name>
    <message>
        <source> (Change: %1 %2)</source>
        <translation type="obsolete"> (Verzió: %1 %2)</translation>
    </message>
    <message>
        <source>There are %1 windows and %2 tabs open
Do you want to quit anyway?</source>
        <translation>Jelenleg %1 böngészőablakban %2 lap van megnyitva
Biztosan ki akar lépni?</translation>
    </message>
    <message>
        <source>Restore failed</source>
        <translation>A visszaállítás sikertelen</translation>
    </message>
    <message>
        <source>The saved session will not be restored because Arora crashed while trying to restore this session.</source>
        <translation type="obsolete">Az elmentett munkamenet nem kerül visszaállításra, mert az Arora összeomlott a művelet közben.</translation>
    </message>
    <message>
        <source>Arora crashed while trying to restore this session.  Should I try again?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BrowserMainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fájl</translation>
    </message>
    <message>
        <source>&amp;New Window</source>
        <translation>Új &amp;ablak</translation>
    </message>
    <message>
        <source>&amp;Open File...</source>
        <translation>&amp;Fájl megnyitása...</translation>
    </message>
    <message>
        <source>Open &amp;Location...</source>
        <translation>&amp;Cím megnyitása...</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>Mentés más&amp;ként...</translation>
    </message>
    <message>
        <source>&amp;Import Bookmarks...</source>
        <translation>Könyvjelzők &amp;importálása...</translation>
    </message>
    <message>
        <source>&amp;Export Bookmarks...</source>
        <translation>Könyvjelzők &amp;exportálása...</translation>
    </message>
    <message>
        <source>P&amp;rint Preview...</source>
        <translation>Ny&amp;omtatás előnézete...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Nyomtatás...</translation>
    </message>
    <message>
        <source>Private &amp;Browsing...</source>
        <translation>&amp;Privát böngészés...</translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation>Ablak bezárása</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Kilépés</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Szerkesztés</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Visszavonás</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>Új&amp;ra végrehajtás</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Ki&amp;vágás</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Másolás</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Beillesztés</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Keresés</translation>
    </message>
    <message>
        <source>Find Nex&amp;t</source>
        <translation>K&amp;övetkező keresése</translation>
    </message>
    <message>
        <source>Find P&amp;revious</source>
        <translation>E&amp;lőző keresése</translation>
    </message>
    <message>
        <source>Prefere&amp;nces...</source>
        <translation type="obsolete">&amp;Beállítások...</translation>
    </message>
    <message>
        <source>Ctrl+,</source>
        <translation>Ctrl+,</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Nézet</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Shift+Ctrl+B</source>
        <translation type="obsolete">Shift+Ctrl+B</translation>
    </message>
    <message>
        <source>Ctrl+/</source>
        <translation>Ctrl+/</translation>
    </message>
    <message>
        <source>Show Menu Bar</source>
        <translation>Menüsor megjelenítése</translation>
    </message>
    <message>
        <source>&amp;Reload Page</source>
        <translation>Oldal &amp;újratöltése</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>Á&amp;llj</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Nagyítás</translation>
    </message>
    <message>
        <source>Zoom &amp;Normal</source>
        <translation>N&amp;ormál méret</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Kicsinyítés</translation>
    </message>
    <message>
        <source>Zoom &amp;Text Only</source>
        <translation>Csak a &amp;szöveg nagyítása</translation>
    </message>
    <message>
        <source>Page S&amp;ource</source>
        <translation>Oldal &amp;forrása</translation>
    </message>
    <message>
        <source>Ctrl+Alt+U</source>
        <translation>Ctrl+Alt+U</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Teljes képernyő</translation>
    </message>
    <message>
        <source>Hi&amp;story</source>
        <translation>Elő&amp;zmények</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Vissza</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Előre</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Kezdőlap</translation>
    </message>
    <message>
        <source>Restore Last Session</source>
        <translation>Utolsó munkamenet visszaállítása</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Könyvjelzők</translation>
    </message>
    <message>
        <source>Show All Bookmarks...</source>
        <translation>Könyvjelzők kezelése...</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Hozzáadás a könyvjelzőkhöz...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation>Könyvjelzőmappa hozzáadása...</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ablak</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Eszközök</translation>
    </message>
    <message>
        <source>Web &amp;Search</source>
        <translation>&amp;Webes keresés</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <comment>Web Search</comment>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>&amp;Clear Private Data</source>
        <translation>&amp;Személyes adatok törlése</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <comment>Clear Private Data</comment>
        <translation>Ctrl+Shift+Delete</translation>
    </message>
    <message>
        <source>Show &amp;Network Monitor</source>
        <translation type="obsolete">&amp;Hálózatfigyelő megjelenítése</translation>
    </message>
    <message>
        <source>Enable Web &amp;Inspector</source>
        <translation>Webfelügyelő &amp;engedélyezése</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Súgó</translation>
    </message>
    <message>
        <source>Switch application language </source>
        <translation>Más alkalmazásnyelv</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Névjegy: &amp;Qt</translation>
    </message>
    <message>
        <source>About &amp;%1</source>
        <comment>About Browser</comment>
        <translation>&amp;Névjegy: %1</translation>
    </message>
    <message>
        <source>Navigation</source>
        <translation>Navigáció</translation>
    </message>
    <message>
        <source>Show Status Bar</source>
        <translation>Állapotsor megjelenítése</translation>
    </message>
    <message>
        <source>Hide Status Bar</source>
        <translation>Állapotsor elrejtése</translation>
    </message>
    <message>
        <source>Show Toolbar</source>
        <translation>Eszköztár megjelenítése</translation>
    </message>
    <message>
        <source>Hide Toolbar</source>
        <translation>Eszköztár elrejtése</translation>
    </message>
    <message>
        <source>Show Bookmarks Bar</source>
        <translation>Könyvjelző eszköztár megjelenítése</translation>
    </message>
    <message>
        <source>Hide Bookmarks Bar</source>
        <translation>Könyvjelző eszköztár elrejtése</translation>
    </message>
    <message>
        <source>%1 - Arora</source>
        <comment>Page title and Browser name</comment>
        <translation>%1 - Arora</translation>
    </message>
    <message>
        <source>Open Web Resource</source>
        <translation>Webes tartalom megnyitása</translation>
    </message>
    <message>
        <source>Web Resources (*.html *.htm *.svg *.png *.gif *.svgz);;All files (*.*)</source>
        <translation>Webes tartalom (*.html *.htm *.svg *.png *.gif *.svgz);;Minden fájl (*.*)</translation>
    </message>
    <message>
        <source>Print Document</source>
        <translation>Dokumentum nyomtatása</translation>
    </message>
    <message>
        <source>Are you sure you want to turn on private browsing?</source>
        <translation>Biztosan be akarja kapcsolni a privát böngészést?</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Ha a privát böngészés be van kapcsolva, akkor néhány személyes adatokat érintő művelet tiltásra kerül:&lt;ul&gt;&lt;li&gt; A meglátogatott oldalak nem kerülnek hozzáadásra az előzményekhez.&lt;/li&gt;&lt;li&gt; Az új elemek automatikusan eltávolításra kerülnek a letöltések listájáról.&lt;/li&gt;&lt;li&gt; Az új sütik nem kerülnek eltárolásra, a korábban tárolt sütik pedig nem érhetőek el.&lt;/li&gt;&lt;li&gt; Az oldalak ikonjai és a munkamenetek nem kerülnek mentésre.&lt;/li&gt;&lt;li&gt; A keresések nem kerülnek hozzáadásra a keresőmező listájához.&lt;/li&gt;&lt;/ul&gt;A böngészőablak bezárásáig a Vissza és Előre gombokkal navigálhatunk a megnyitott oldalak között.</translation>
    </message>
    <message>
        <source>Are you sure you want to close the window?  There are %1 tabs open</source>
        <translation>Biztosan be akarja zárni az ablakot?  Jelenleg %1 lap van megnyitva</translation>
    </message>
    <message>
        <source>Web Inspector</source>
        <translation>Webfelügyelő</translation>
    </message>
    <message>
        <source>The web inspector will only work correctly for pages that were loaded after enabling.
Do you want to reload all pages?</source>
        <translation>A webfelügyelő csak azokkal az oldalakkal fog rendeltetésszerűen működni, amelyek az aktiválása előtt kerültek megnyitásra.
Újra akar tölteni minden oldalt?</translation>
    </message>
    <message>
        <source>Stop loading the current page</source>
        <translation>Oldal letöltésének megszakítása</translation>
    </message>
    <message>
        <source>Reload the current page</source>
        <translation>Oldal újratöltése</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Letöltések</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <comment>Download Manager</comment>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Alapértelmezett</translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation>Szövegkódolás</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+Ctrl+B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Options...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure Search Engines...</source>
        <translation type="unfinished">Keresőmotorok beállítása...</translation>
    </message>
    <message>
        <source>&amp;Ad Block...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When private browsing is turned on, some actions concerning your privacy will be disabled:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Webpages are not added to the history.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items are automatically removed from the Downloads window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New cookies are not stored, current cookies can&apos;t be accessed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Site icons won&apos;t be stored.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Session won&apos;t be saved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Searches are not added to the pop-up menu in the search box.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No new network cache is written to disk.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Private Browsing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Törlés</translation>
    </message>
</context>
<context>
    <name>ClearPrivateData</name>
    <message>
        <source>Clear Private Data</source>
        <translation>Személyes adatok törlése</translation>
    </message>
    <message>
        <source>Clear the following items:</source>
        <translation>A következő elemek törlése:</translation>
    </message>
    <message>
        <source>&amp;Browsing History</source>
        <translation>Böngészési &amp;előzmények</translation>
    </message>
    <message>
        <source>&amp;Download History</source>
        <translation>&amp;Letöltési előzmények</translation>
    </message>
    <message>
        <source>&amp;Search History</source>
        <translation>&amp;Keresési előzmények</translation>
    </message>
    <message>
        <source>&amp;Cookies</source>
        <translation>&amp;Sütik</translation>
    </message>
    <message>
        <source>C&amp;ached Web Pages</source>
        <translation>Kapcs&amp;olat nélküli webhelyadatok</translation>
    </message>
    <message>
        <source>Website &amp;Icons</source>
        <translation>Oldalak &amp;ikonjai</translation>
    </message>
    <message>
        <source>Clear &amp;Private Data</source>
        <translation>&amp;Személyes adatok törlése</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Mégsem</translation>
    </message>
</context>
<context>
    <name>ClickToFlash</name>
    <message>
        <source>Load</source>
        <translation>Betöltés</translation>
    </message>
    <message>
        <source>Load All</source>
        <translation>Összes betöltése</translation>
    </message>
    <message>
        <source>Add %1 to Whitelist</source>
        <translation>%1 hozzáadása az engedélyezési listához</translation>
    </message>
    <message>
        <source>Remove from Whitelist</source>
        <translation>Eltávolítás az engedélyezési listáról</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>Load Flash</source>
        <translation>Flash betöltése</translation>
    </message>
</context>
<context>
    <name>ClickToFlashSettings</name>
    <message>
        <source>Whitelist sites</source>
        <translation>Engedélyezett oldalak</translation>
    </message>
</context>
<context>
    <name>CookieExceptionsModel</name>
    <message>
        <source>Website</source>
        <translation>Oldal</translation>
    </message>
    <message>
        <source>Rule</source>
        <translation>Szabály</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Engedélyezés</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Tiltás</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Engedélyezés a munkamenetre</translation>
    </message>
</context>
<context>
    <name>CookieModel</name>
    <message>
        <source>Website</source>
        <translation>Oldal</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Útvonal</translation>
    </message>
    <message>
        <source>Secure</source>
        <translation>Biztonságos</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Lejárat</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Tartalmak</translation>
    </message>
    <message>
        <source>true</source>
        <translation>igen</translation>
    </message>
    <message>
        <source>false</source>
        <translation>nem</translation>
    </message>
    <message>
        <source>Session cookie</source>
        <translation>Ideiglenes süti</translation>
    </message>
</context>
<context>
    <name>CookiesDialog</name>
    <message>
        <source>Cookies</source>
        <translation>Sütik</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Eltávolítás</translation>
    </message>
    <message>
        <source>Remove &amp;All Cookies</source>
        <translation>&amp;Összes süti eltávolítása</translation>
    </message>
    <message>
        <source>Add &amp;Rule</source>
        <translation>&amp;Szabály hozzáadása</translation>
    </message>
</context>
<context>
    <name>CookiesExceptionsDialog</name>
    <message>
        <source>Cookie Exceptions</source>
        <translation>Süti kivételek</translation>
    </message>
    <message>
        <source>New Exception</source>
        <translation>Új kivétel</translation>
    </message>
    <message>
        <source>Domain:</source>
        <translation>Domain:</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Tiltás</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Engedélyezés a munkamenetre</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Engedélyezés</translation>
    </message>
    <message>
        <source>Exceptions</source>
        <translation>Kivételek</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Eltávolítás</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>&amp;Összes eltávolítása</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Letöltések</translation>
    </message>
    <message>
        <source>Clean up</source>
        <translation>Lista törlése</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 elem</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Letöltés</translation>
    </message>
    <message>
        <source>Ico</source>
        <translation>Ico</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Fájlnév</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Újra</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Állj</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Fájl mentése</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Letöltés megszakítva: %1</translation>
    </message>
    <message>
        <source>Error opening output file: %1</source>
        <translation>Hiba a kimeneti fájl megnyitásánál: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Hiba a mentésnél: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Hálózati hiba: %1</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) - %4</source>
        <translation>%1 / %2 (%3/mp) - %4</translation>
    </message>
    <message>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 / %2 - Megállítva</translation>
    </message>
    <message>
        <source>Download directory (%1) couldn&apos;t be created.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>There are %1 downloads in progress
Do you want to quit anyway?</source>
        <translation>Jelenleg %1 letöltés van folyamatban.
Biztosan ki akar lépni?</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation>
            <numerusform>%n letöltés</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minutes remaining</source>
        <translation>
            <numerusform>%n perc van hátra</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n seconds remaining</source>
        <translation>
            <numerusform>%n másodperc van hátra</numerusform>
        </translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bájt</translation>
    </message>
    <message>
        <source>kB</source>
        <translation>kB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>GB</source>
        <translation>GB</translation>
    </message>
</context>
<context>
    <name>FileAccessReply</name>
    <message>
        <source>No Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error opening: %1: No such file or directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to read %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contents of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlése</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Előzmények</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Eltávolítás</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>&amp;Összes eltávolítása</translation>
    </message>
</context>
<context>
    <name>HistoryMenu</name>
    <message>
        <source>Show All History</source>
        <translation>Összes előzmény megjelenítése</translation>
    </message>
    <message>
        <source>Clear History...</source>
        <translation>Előzmények törlése...</translation>
    </message>
    <message>
        <source>Clear History</source>
        <translation>Előzmények törlése</translation>
    </message>
    <message>
        <source>Do you want to clear the history?</source>
        <translation>Törölni akarja az előzményeket?</translation>
    </message>
</context>
<context>
    <name>HistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Cím</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Hivatkozás</translation>
    </message>
</context>
<context>
    <name>HistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Korábban a mai napon</translation>
    </message>
    <message numerus="yes">
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n elem</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>JavaScriptAroraObject</name>
    <message>
        <source>Welcome to Arora!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arora Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search results provided by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Arora</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LanguageManager</name>
    <message>
        <source>No translation files are installed.</source>
        <translation type="obsolete">Nincs telepített fordítási fájl.</translation>
    </message>
    <message>
        <source>Choose language</source>
        <translation>Nyelv kiválasztása</translation>
    </message>
    <message>
        <source>&lt;p&gt;You can run with a different language than&lt;br&gt;the operating system default.&lt;/p&gt;&lt;p&gt;Please choose the language which should be used&lt;/p&gt;</source>
        <translation>&lt;b&gt;Az operációs rendszer alapértelmezett nyelvén kívül választható további nyelv is.&lt;/p&gt;&lt;p&gt;Válassza ki a használni kívánt nyelvet!&lt;/p&gt;</translation>
    </message>
    <message>
        <source>No translation files are installed at %1.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Adja meg &quot;%1&quot; felhasználónevét és jelszavát itt: %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Connect to proxy &quot;%1&quot; using:&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Csatlakozás a(z) &quot;%1&quot; proxyhoz:&lt;/qt&gt;</translation>
    </message>
    <message>
        <source> - SSL Errors</source>
        <translation> - SSL hibák</translation>
    </message>
    <message>
        <source>&lt;qt&gt;SSL Errors:&lt;br/&gt;&lt;br/&gt;for: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Do you want to ignore these errors?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;SSL hibák:&lt;br/&gt;&lt;br/&gt; &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Figyelmen kívül akarja hagyni ezeket a hibákat?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Certificates:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Tanúsítványok:&lt;br/&gt;%1&lt;br/&gt;El akarja fogadni ezeket a tanúsítványokat?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Issuer: %1</source>
        <translation>Kibocsátó: %1</translation>
    </message>
    <message>
        <source>Not valid before: %1</source>
        <translation>Nem érvényes ezelőtt: %1</translation>
    </message>
    <message>
        <source>Valid until: %1</source>
        <translation>Érvényes eddig: %1</translation>
    </message>
    <message>
        <source>Alternate Names:</source>
        <translation>Alternatív nevek:</translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Name</source>
        <translation type="obsolete">Név</translation>
    </message>
    <message>
        <source>Value</source>
        <translation type="obsolete">Érték</translation>
    </message>
</context>
<context>
    <name>NetworkMonitorDialog</name>
    <message>
        <source>Network Monitor</source>
        <translation type="obsolete">Hálózatfigyelő</translation>
    </message>
    <message>
        <source>Network Requests</source>
        <translation type="obsolete">Hálózati kérések</translation>
    </message>
    <message>
        <source>Request Headers</source>
        <translation type="obsolete">Kérés fejlécek</translation>
    </message>
    <message>
        <source>Response Headers</source>
        <translation type="obsolete">Válasz fejlécek</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="obsolete">&amp;Eltávolítás</translation>
    </message>
    <message>
        <source>Remove &amp;All Requests</source>
        <translation type="obsolete">&amp;Összes kérés eltávolítása</translation>
    </message>
</context>
<context>
    <name>OpenSearchDialog</name>
    <message>
        <source>Open File</source>
        <translation>Fájl megnyitása</translation>
    </message>
    <message>
        <source>OpenSearch</source>
        <translation>Keresőmotorok</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>%1 is not a valid OpenSearch 1.1 description or is already on your list.</source>
        <translation>%1 nem érvényes OpenSearch 1.1 leírás, vagy már szerepel a listán.</translation>
    </message>
    <message>
        <source>You must have at least one search engine in here.</source>
        <translation>Legalább egy keresőmotor szükséges.</translation>
    </message>
    <message>
        <source>OpenSearch Manager</source>
        <translation>Keresőmotorok kezelése</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Hozzáadás</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Törlés</translation>
    </message>
    <message>
        <source>&amp;Restore Defaults</source>
        <translation>&amp;Alapértelmezések visszaállítása</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Bezárás</translation>
    </message>
</context>
<context>
    <name>OpenSearchEngineModel</name>
    <message>
        <source>&lt;strong&gt;Description:&lt;/strong&gt; %1</source>
        <translation>&lt;strong&gt;Leírás:&lt;/strong&gt; %1</translation>
    </message>
    <message>
        <source>&lt;strong&gt;Provides contextual suggestions&lt;/strong&gt;</source>
        <translation>&lt;strong&gt;Javaslatokat szolgáltat&lt;/strong&gt;</translation>
    </message>
    <message>
        <source>Comma-separated list of keywords that may be entered in the location barfollowed by search terms to search with this engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">Név</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSearchManager</name>
    <message>
        <source>Do you want to add the following engine to your list of search engines?&lt;br /&gt;&lt;br /&gt;Name: %1&lt;br /&gt;Searches on: %2</source>
        <translation>Hozzá akarja adni ezt a keresőmotort a listához?&lt;br /&gt;&lt;br /&gt;Név: %1&lt;br /&gt;Keresés itt: %2</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Azonosítás szükséges</translation>
    </message>
    <message>
        <source>DUMMY ICON</source>
        <translation>DUMMY ICON</translation>
    </message>
    <message>
        <source>INTRO TEXT DUMMY</source>
        <translation>INTRO TEXT DUMMY</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Felhasználónév:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Jelszó:</translation>
    </message>
</context>
<context>
    <name>PlainTextEditSearch</name>
    <message>
        <source>Not Found</source>
        <translation>Nincs találat</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Proxy azonosítás</translation>
    </message>
    <message>
        <source>Connect to proxy</source>
        <translation>Kapcsolódás a proxyhoz</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Felhasználónév:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Jelszó:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The file is not an OpenSearch 1.1 file.</source>
        <translation>A fájl nem egy OpenSearch 1.1 fájl.</translation>
    </message>
    <message>
        <source>The file is not an XBEL version 1.0 file.</source>
        <translation>A fájl nem egy XBEL 1.0 fájl.</translation>
    </message>
    <message>
        <source>Unknown title</source>
        <translation>Ismeretlen cím</translation>
    </message>
</context>
<context>
    <name>RequestModel</name>
    <message>
        <source>Redirect: %1</source>
        <translation type="obsolete">Átirányítás: %1</translation>
    </message>
    <message>
        <source>Method</source>
        <translation type="obsolete">Típus</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="obsolete">Cím</translation>
    </message>
    <message>
        <source>Response</source>
        <translation type="obsolete">Válasz</translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="obsolete">Hossz</translation>
    </message>
    <message>
        <source>Content Type</source>
        <translation type="obsolete">Tartalom típusa</translation>
    </message>
    <message>
        <source>Info</source>
        <translation type="obsolete">Információ</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Ismeretlen</translation>
    </message>
</context>
<context>
    <name>SearchBanner</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Keresés</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Bezárás</translation>
    </message>
    <message>
        <source>Highlight All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Preferences</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Általános</translation>
    </message>
    <message>
        <source>On startup:</source>
        <translation>Induláskor:</translation>
    </message>
    <message>
        <source>Show my home page</source>
        <translation>Kezdőlap megjelenítése</translation>
    </message>
    <message>
        <source>Show a blank page</source>
        <translation>Üres oldal megjelenítése</translation>
    </message>
    <message>
        <source>Restore windows and tabs from last time</source>
        <translation>Legutóbbi ablakok és lapok visszaállítása</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Kezdőlap:</translation>
    </message>
    <message>
        <source>Set to current page</source>
        <translation>Beállítás az aktuális oldalra</translation>
    </message>
    <message>
        <source>Remove history items:</source>
        <translation>Előzmények eltávolítása:</translation>
    </message>
    <message>
        <source>After one day</source>
        <translation>Egy nap után</translation>
    </message>
    <message>
        <source>After one week</source>
        <translation>Egy hét után</translation>
    </message>
    <message>
        <source>After two weeks</source>
        <translation>Két hét után</translation>
    </message>
    <message>
        <source>After one month</source>
        <translation>Egy hónap után</translation>
    </message>
    <message>
        <source>After one year</source>
        <translation>Egy év után</translation>
    </message>
    <message>
        <source>Manually</source>
        <translation>Manuálisan</translation>
    </message>
    <message>
        <source>On application exit</source>
        <translation>Kilépéskor</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Letöltések</translation>
    </message>
    <message>
        <source>Ask for a destination each time</source>
        <translation>Rákérdezés a letöltés helyére minden alkalommal</translation>
    </message>
    <message>
        <source>Use this destination:</source>
        <translation>Letöltések helyének megadása:</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Megjelenés</translation>
    </message>
    <message>
        <source>Standard font:</source>
        <translation>Általános betűtípus:</translation>
    </message>
    <message>
        <source>Select...</source>
        <translation>Kiválasztás...</translation>
    </message>
    <message>
        <source>Fixed-width font:</source>
        <translation>Rögzített szélességű betűtípus:</translation>
    </message>
    <message>
        <source>Preferred languages for viewing webpages in:</source>
        <translation>Oldalak megtekintésekor előnyben részesített nyelvek:</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Adatvédelem</translation>
    </message>
    <message>
        <source>Web Content</source>
        <translation>Webes tartalom</translation>
    </message>
    <message>
        <source>Block Popup Windows</source>
        <translation>Felugró ablakok blokkolása</translation>
    </message>
    <message>
        <source>Enable Plugins</source>
        <translation>Bővítmények engedélyezése</translation>
    </message>
    <message>
        <source>Use ClickToFlash on flash plugins</source>
        <translation>Flash tartalmak megjelenítése kattintásra</translation>
    </message>
    <message>
        <source>Enable Javascript</source>
        <translation>Javascript engedélyezése</translation>
    </message>
    <message>
        <source>View Images</source>
        <translation>Képek megjelenítése</translation>
    </message>
    <message>
        <source>Cookies</source>
        <translation>Sütik</translation>
    </message>
    <message>
        <source>Accept Cookies:</source>
        <translation>Sütik elfogadása:</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>Mindig</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Soha</translation>
    </message>
    <message>
        <source>Only from sites you navigate to</source>
        <translation>Csak a meglátogatott oldalakon</translation>
    </message>
    <message>
        <source>Exceptions...</source>
        <translation>Kivételek...</translation>
    </message>
    <message>
        <source>Keep Cookies Until:</source>
        <translation>Sütik megtartása:</translation>
    </message>
    <message>
        <source>They expire</source>
        <translation>Lejáratig</translation>
    </message>
    <message>
        <source>I exit the application</source>
        <translation>Kilépésig</translation>
    </message>
    <message>
        <source>At most 90 days</source>
        <translation>Legfeljebb 90 napig</translation>
    </message>
    <message>
        <source>Cookies...</source>
        <translation>Sütik...</translation>
    </message>
    <message>
        <source>Filter Tracking Cookies</source>
        <translation>Nyomkövető sütik szűrése</translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation>Lapok</translation>
    </message>
    <message>
        <source>Select tabs and windows as they are created</source>
        <translation>Lapok és ablakok kiválasztása megnyitáskor</translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs or windows</source>
        <translation>Megerősítés kérése több lap vagy ablak bezárásakor</translation>
    </message>
    <message>
        <source>Show only one close button instead of one for each tab</source>
        <translation>Csak egy bezárás gomb megjelenítése</translation>
    </message>
    <message>
        <source>Quit the application when last tab is closed</source>
        <translation>Kilépés az alkalmazásból az utolsó lap bezárásakor</translation>
    </message>
    <message>
        <source>Opening links</source>
        <translation>Hivatkozások megnyitása</translation>
    </message>
    <message>
        <source>Links that want to open in a new window:</source>
        <translation>Az új ablakban megnyitandó hivatkozások:</translation>
    </message>
    <message>
        <source>In a new window</source>
        <translation>Új ablakban</translation>
    </message>
    <message>
        <source>In a new selected tab in the current window</source>
        <translation>Az aktuális ablakban, új aktív lapon</translation>
    </message>
    <message>
        <source>In a new tab in the current window</source>
        <translation>Az aktuális ablakban, új lapon</translation>
    </message>
    <message>
        <source>In the current tab</source>
        <translation>Az aktuális lapon</translation>
    </message>
    <message>
        <source>Open links from applications:</source>
        <translation>Külső hivatkozások megnyitása:</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Use proxy server</source>
        <translation>Proxy kiszolgáló használata</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Típus:</translation>
    </message>
    <message>
        <source>Socks5</source>
        <translation>Socks5</translation>
    </message>
    <message>
        <source>Http (Secure)</source>
        <translation>Http (biztonságos)</translation>
    </message>
    <message>
        <source>Http (Transparent)</source>
        <translation>Http (nem biztonságos)</translation>
    </message>
    <message>
        <source>Host name:</source>
        <translation>Kiszolgáló:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>User Name:</source>
        <translation>Felhasználónév:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Jelszó:</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Haladó</translation>
    </message>
    <message>
        <source>Style Sheet:</source>
        <translation>Stíluslap:</translation>
    </message>
    <message>
        <source>Enable network cache</source>
        <translation>Hálózati gyorstár engedélyezése</translation>
    </message>
    <message>
        <source>Maximum Size:</source>
        <translation>Maximális méret:</translation>
    </message>
    <message>
        <source> MB</source>
        <translation> MB</translation>
    </message>
    <message>
        <source>Use the default search engine as fallback when the URL given by the user is invalid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose Directory...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A cookie session ends:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When I exit the application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>30 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AutoFill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AutoFill web forms:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User names and passwords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Restart required</source>
        <translation>Újraindítás szükséges</translation>
    </message>
    <message>
        <source>The network cache configuration has changed. So that it can be taken into account, the browser has to be restarted.</source>
        <translation>A hálózati gyorstárazás beállításai megváltoztak. A módosítások használatához a böngésző újraindítása szükséges.</translation>
    </message>
    <message>
        <source>Choose Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose CSS File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SourceViewer</name>
    <message>
        <source>Loading...</source>
        <translation>Betöltés...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Szerkesztés</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Keresés</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="obsolete">&amp;Nézet</translation>
    </message>
    <message>
        <source>&amp;Wrap lines</source>
        <translation type="obsolete">&amp;Sorok tördelése</translation>
    </message>
    <message>
        <source>Source of Page </source>
        <translation type="obsolete">Oldal forrása</translation>
    </message>
    <message>
        <source>Source of Page %1</source>
        <translation>%1 oldal forrása</translation>
    </message>
</context>
<context>
    <name>TabBar</name>
    <message>
        <source>Show Tab Bar</source>
        <translation>Lapok megjelenítése</translation>
    </message>
    <message>
        <source>Hide Tab Bar</source>
        <translation>Lapok elrejtése</translation>
    </message>
    <message>
        <source>Duplicate Tab</source>
        <translation>Lap megkettőzése</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Lap bezárása</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>&amp;Többi lap bezárása</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Lap újratöltése</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Összes lap újratöltése</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>Untitled</source>
        <translation>Névtelen</translation>
    </message>
    <message>
        <source>Saved Tabs</source>
        <translation>Mentett lapok</translation>
    </message>
    <message>
        <source>Do you really want to close this page?</source>
        <translation>Biztosan be akarja zárni ezt az oldalt?</translation>
    </message>
    <message>
        <source>You have modified this page and when closing it you would lose the modification.
Do you really want to close this page?
</source>
        <translation>Az oldalon elvégzett módosítások bezáráskor elveszhetnek.
Biztosan be akarja zárni ezt az oldalt?
</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Töltés...</translation>
    </message>
    <message>
        <source>Loading %1% (%2 %3)...</source>
        <translation>Töltés %1% (%2 %3)...</translation>
    </message>
    <message>
        <source>Finished loading</source>
        <translation>A letöltés befejeződött</translation>
    </message>
    <message>
        <source>Failed to load</source>
        <translation>A letöltés sikertelen</translation>
    </message>
    <message>
        <source>Show Next Tab</source>
        <translation>Következő lap megjelenítése</translation>
    </message>
    <message>
        <source>Ctrl-]</source>
        <translation>Ctrl-]</translation>
    </message>
    <message>
        <source>Show Previous Tab</source>
        <translation>Előző lap megjelenítése</translation>
    </message>
    <message>
        <source>Ctrl-[</source>
        <translation>Ctrl-[</translation>
    </message>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Nemrég bezárt lapok</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation>Új &amp;lap</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>Lap &amp;bezárása</translation>
    </message>
    <message>
        <source>Bookmark All Tabs</source>
        <translation>Összes lap felvétele a könyvjelzők közé</translation>
    </message>
</context>
<context>
    <name>ToolbarSearch</name>
    <message>
        <source>Suggestions</source>
        <translation>Javaslatok</translation>
    </message>
    <message>
        <source>Add &apos;%1&apos;</source>
        <translation>&apos;%1&apos; hozzáadása</translation>
    </message>
    <message>
        <source>Configure Search Engines...</source>
        <translation type="obsolete">Keresőmotorok beállítása...</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Keresési előzmények törlése</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Nincsenek keresési előzmények</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Keresési előzmények</translation>
    </message>
</context>
<context>
    <name>WebPage</name>
    <message>
        <source>Error loading page: %1</source>
        <translation>Hiba a következő oldal betöltésekor: %1</translation>
    </message>
    <message>
        <source>When connecting to: %1.</source>
        <translation>Kapcsolódás: %1.</translation>
    </message>
    <message>
        <source>Check the address for errors such as &lt;b&gt;ww&lt;/b&gt;.arora-browser.org instead of &lt;b&gt;www&lt;/b&gt;.arora-browser.org</source>
        <translation>Nem vétett hibát a hivatkozás beírásakor? (pl. &quot;&lt;b&gt;ww&lt;/b&gt;.arora-browser.org&quot; a &quot;&lt;b&gt;www&lt;/b&gt;.arora-browser.org&quot; helyett)</translation>
    </message>
    <message>
        <source>If the address is correct, try checking the network connection.</source>
        <translation>Amennyiben a hivatkozás helyes, próbálja ellenőrizni a hálózati kapcsolatot.</translation>
    </message>
    <message>
        <source>If your computer or network is protected by a firewall or proxy, make sure that the browser is permitted to access the network.</source>
        <translation>Ha a számítógép vagy a hálózat tűzfal, illetve proxy mögött van, a hálózat eléréséhez megfelelő hozzáférési jogosultság szükséges.</translation>
    </message>
    <message>
        <source>Resending POST request</source>
        <translation>POST kérés újraküldése</translation>
    </message>
    <message>
        <source>In order to display the site, the request along with all the data must be sent once again, which may lead to some unexpected behaviour of the site e.g. the same action might be performed once again. Do you want to continue anyway?</source>
        <translation>Az oldal megjelenítéséhez az űrlapot minden adattal együtt újra el kell küldeni. A kétszer végrehajtott megegyező művelet az oldalon nem várt komplikációkkal járhat. Biztosan folytatni szeretné?</translation>
    </message>
</context>
<context>
    <name>WebView</name>
    <message>
        <source>Open in New &amp;Window</source>
        <translation>Megnyitás új &amp;ablakban</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>Megnyitás új &amp;lapon</translation>
    </message>
    <message>
        <source>Save Lin&amp;k</source>
        <translation>Hivatkozás &amp;mentése</translation>
    </message>
    <message>
        <source>&amp;Bookmark This Link</source>
        <translation>Hivatkozás &amp;felvétele a könyvjelzők közé</translation>
    </message>
    <message>
        <source>&amp;Copy Link Location</source>
        <translation>Hivatkozá&amp;s másolása</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Window</source>
        <translation>&amp;Kép megnyitása új ablakban</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Tab</source>
        <translation>Ké&amp;p megnyitása új lapon</translation>
    </message>
    <message>
        <source>&amp;Save Image</source>
        <translation>&amp;Kép mentése</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation>Kép m&amp;ásolása</translation>
    </message>
    <message>
        <source>C&amp;opy Image Location</source>
        <translation>Kép &amp;hivatkozásának másolása</translation>
    </message>
    <message>
        <source>Search with...</source>
        <translation>Keresés mással...</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Töltés...</translation>
    </message>
    <message>
        <source>Add to the toolbar search</source>
        <translation>Hozzáadás az eszköztár keresőmezőjéhez</translation>
    </message>
    <message>
        <source>Method not supported</source>
        <translation>Az eljárás nem támogatott</translation>
    </message>
    <message>
        <source>%1 method is not supported.</source>
        <translation>%1 eljárás nem támogatott.</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Keresőmotor</translation>
    </message>
    <message>
        <source>Choose the desired search engine</source>
        <translation>Válassza ki a kívánt keresőmotort</translation>
    </message>
    <message>
        <source>Engine name</source>
        <translation>Motor neve</translation>
    </message>
    <message>
        <source>Type in a name for the engine</source>
        <translation>Adjon meg egy nevet a motornak</translation>
    </message>
    <message>
        <source>Block Image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebViewSearch</name>
    <message>
        <source>Not Found</source>
        <translation>Nincs találat</translation>
    </message>
</context>
</TS>
